==> enterprisemodules-ora_config-3.20.0.tar.gz: enterprisemodules-ora_config-3.20.0/lib/puppet/feature/oracle11.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
#
# Default features are not rechecked. SO that is why we do the difficult solution.
# Check https://tickets.puppetlabs.com/browse/PUP-5985?jql=text~%22feature%20evaluation%22
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/oracle/settings'
require 'puppet_x/enterprisemodules/oracle/access'
require 'puppet_x/enterprisemodules/oracle/information'
# rubocop:disable Style/Documentation
module OracleFeature
  # rubocop:enable Style/Documentation
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::Settings
  include Puppet_X::EnterpriseModules::Oracle::Information

  def self.sid
    default_database_sid.nil? ? running_normal_database_sids.first : default_database_sid
  end

  def self.oracle11_check
    Puppet.debug 'Feature oracle11 checking availability'
    Puppet.debug "Feature oracle11 sid is '#{sid}'"
    Puppet.debug "Feature oracle11 database version is #{database_version}"

    if sid && /^11.*$/.match(database_version)
      Puppet.debug 'Feature oracle11 available'
      true
    else
      Puppet.debug 'Feature oracle11 **NOT** available'
      false
    end
  rescue StandardError => e
    Puppet.debug e # Show the generated error
    Puppet.debug 'Feature oracle11 **NOT** available'
    false
  end

  Puppet.features.add(:oracle11) do
    oracle11_check
  end

  Puppet.features.send :meta_def, 'oracle11?' do
    name = :oracle11
    final = @results[name]
    @results[name] = OracleFeature.oracle11_check unless final
    @results[name]
  end
end

==> enterprisemodules-ora_config-3.22.2.tar.gz: enterprisemodules-ora_config-3.22.2/lib/puppet/feature/oracle11.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
#
# Default features are not rechecked. SO that is why we do the difficult solution.
# Check https://tickets.puppetlabs.com/browse/PUP-5985?jql=text~%22feature%20evaluation%22
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/oracle/settings'
require 'puppet_x/enterprisemodules/oracle/access'
require 'puppet_x/enterprisemodules/oracle/information'
# rubocop:disable Style/Documentation
module OracleFeature
  # rubocop:enable Style/Documentation
  include PuppetX::EnterpriseModules::Oracle::Access
  include PuppetX::EnterpriseModules::Oracle::Settings
  include PuppetX::EnterpriseModules::Oracle::Information

  def self.sid
    default_database_sid.nil? ? running_normal_database_sids.first : default_database_sid
  end

  def self.oracle11_check
    Puppet.debug 'Feature oracle11 checking availability'
    Puppet.debug "Feature oracle11 sid is '#{sid}'"
    Puppet.debug "Feature oracle11 database version is #{database_version}"

    if sid && /^11.*$/.match(database_version)
      Puppet.debug 'Feature oracle11 available'
      true
    else
      Puppet.debug 'Feature oracle11 **NOT** available'
      false
    end
  rescue StandardError => e
    Puppet.debug e # Show the generated error
    Puppet.debug 'Feature oracle11 **NOT** available'
    false
  end

  Puppet.features.add(:oracle11) do
    oracle11_check
  end

  Puppet.features.send :meta_def, 'oracle11?' do
    name = :oracle11
    final = @results[name]
    @results[name] = OracleFeature.oracle11_check unless final
    @results[name]
  end
end
